@@ -7,6 +7,8 @@
 import time
 import tempfile
 import os
+from os import listdir
+from os.path import isfile, join
 import json
 import uuid
 import requests
@@ -18,6 +20,8 @@ from shapely.geometry import Polygon
 from vallaris.utils import *
 from IPython.display import display, Javascript, Markdown as md, HTML
 from urllib.parse import urlencode
+import urllib.request
+import zipfile
 from IPython.display import IFrame
 import rasterio
 from rasterio.plot import show
@@ -27,7 +31,6 @@ import matplotlib.pyplot as plt
 import earthpy as et
 import earthpy.spatial as es
 import earthpy.plot as ep
-
 from urllib.request import urlretrieve
 from dotenv import load_dotenv
 load_dotenv()
@@ -661,21 +664,25 @@ def RenderRaster(parameter, *args, **kwargs):
               }
            ]
         }
+        
+        map_id = uuid.uuid4().hex
+        map_id2 = '"'
 
-        def js_convert_str_html_raster(p,url):
-            js_convert = """
-                <iframe width="100%" height=336 src=""></iframe>
+        js_create = """
+                 <iframe id='"""+map_id+"""' width="100%" height=336 src=""></iframe>
                 <script>
                  var myinputstring = '{0}';    
                  var myurl = '{1}';
-                document.querySelector('iframe').setAttribute("src", myurl)
+                document.getElementById("""+map_id2+map_id+map_id2+""").src = myurl
                 function bake_storage(value) {{
                    value ?   localStorage.setItem('params', value) : localStorage.clear()
                 }}
 
                 bake_storage(myinputstring)
                 </script>
-            """.format(p,url)
+            """
+        def js_convert_str_html_raster(p,url):
+            js_convert = js_create.format(p,url)
             return HTML(js_convert)
 
 
@@ -688,6 +695,7 @@ def RenderRaster(parameter, *args, **kwargs):
 
         return display(jsobj)
     
+    
     except Exception as e:
         return 'error display :' + str(e)
 
@@ -734,12 +742,15 @@ def NDVIMap(parameter, *args, **kwargs):
         red = raster.read(parameter['red'])
         nir = raster.read(parameter['nir'])
         np.seterr(divide='ignore', invalid='ignore')
+        c_map = kwargs.get('cmap', 'viridis')
+        minn = kwargs.get('min', -1) 
+        maxx = kwargs.get('max', 1) 
         
         # Calculate ndvi
         ndvi = (nir.astype(float)-red.astype(float))/(nir.astype(float)+red.astype(float))
 
         fig, ax = plt.subplots(figsize = (12, 12))
-        im = ax.imshow(ndvi.squeeze())
+        im = ax.imshow(ndvi.squeeze(), cmap=c_map, vmin=minn, vmax=maxx)
         ep.colorbar(im)
         ax.set(title= title)
         ax.set(xlabel= xlabel +'\n'+'\n'+ '© Vallaris Maps')
@@ -774,7 +785,7 @@ def RGBSave(parameter, *args, **kwargs):
 
         with rasterio.open(parameter['output'], 'w', **ras_meta) as dst:
             # If array is in (x, y, z) order (cols, rows, bands)
-            dst.write(np.moveaxis(nrg, [0, 1, 2], [2, 1, 0]))
+            dst.write(np.moveaxis(nrg, [0, 1, 2], [1, 2, 0]))
             
         return 'Succeed : ' + parameter['output']
             
@@ -811,3 +822,193 @@ def NDVISave(parameter, *args, **kwargs):
     
     except Exception as e:
         return 'error to save :' + str(e)
+
+def GrayMap(parameter, *args, **kwargs):
+
+    title = kwargs.get('title', "Maps")
+    ylabel = kwargs.get('ylabel', "Row #")
+    xlabel = kwargs.get('xlabel', "Column #")
+    minn = kwargs.get('min', "0")
+    maxx = kwargs.get('max', "255")
+    c_map = kwargs.get('cmap', "gray")
+    
+    
+    try :
+    
+        # Open the file:
+        raster = rasterio.open(parameter['data'])
+
+        b1 = raster.read(parameter['band'])
+
+        fig, ax = plt.subplots(figsize = (12, 12))
+        im = ax.imshow(b1.squeeze(), cmap=c_map, vmin=minn, vmax=maxx)
+        ep.colorbar(im)
+        ax.set(title= title)
+        ax.set(xlabel= xlabel +'\n'+'\n'+ '© Vallaris Maps')
+        ax.set(ylabel= ylabel)
+
+        return plt.show()
+    
+    except Exception as e:
+        # print(e)
+        return 'error display :' + str(e)
+
+def GraySave(parameter, *args, **kwargs):
+    nodata = kwargs.get('nodata', -99)
+    dtype = kwargs.get('dtype', "float32")
+    
+    try :
+
+        # Open the file:
+        raster = rasterio.open(parameter['input'])
+
+        image = raster.read(parameter['band'])
+
+        ras_meta = raster.profile
+        ras_meta['count']=1
+        ras_meta['dtype'] = "float32"
+        ras_meta['nodata'] = -99
+
+        with rasterio.open(parameter['output'], 'w', **ras_meta) as dst:
+            dst.write(image,1)
+        
+        return 'Succeed : ' + parameter['output']
+            
+    
+    except Exception as e:
+        print(e)
+        return 'error to save : please check parameter'
+
+
+def SearchData(key_word, *args, **kwargs):
+    
+    try:
+
+        APIKey = '277E01W1DI8YhDYYGre10pi8CTm5N3bQfPx4VX0hRVnjYOuoFIrmmWM1nY6GKVGL'
+
+        url = "https://v2k-dev.vallarismaps.com/core/api/features/1.0/collections?search="+key_word+"&itemType=Coverage"
+
+        payload = {}
+        headers = {
+            'API-Key': APIKey,
+        }
+
+        response = requests.request("GET", url, headers=headers, data=payload)
+        # print(response)
+
+        json_col = response.json()
+        # print(json_col)
+
+        crt = len(json_col['collections'])
+        # print(crt)
+
+        outdata = []
+        for c in range(0, crt):
+            name = json_col['collections'][c]['title']
+        #     getName.append(name)
+            col = json_col['collections'][c]['id']
+        #     getCol.append(col)
+
+            jsonout ={
+                "id": col,
+                "title" : name
+            }
+
+            outdata.append(jsonout)
+
+        return outdata
+    
+    
+    except Exception as e:
+        return 'error :' + str(e)
+
+def ExportCoverage(collection):
+    
+    try :
+
+        APIKey = "277E01W1DI8YhDYYGre10pi8CTm5N3bQfPx4VX0hRVnjYOuoFIrmmWM1nY6GKVGL"
+
+        url = "https://v2k-dev.vallarismaps.com/core/api/coverages/1.0-beta/manager/export/" + str(collection) + '/jobs'
+
+
+        payload = json.dumps({
+          "option": {
+            "mimeType": "original"
+          }
+        })
+        headers = {
+          'API-Key': APIKey,
+          'Content-Type': 'application/json'
+        }
+
+        response = requests.request("POST", url, headers=headers, data=payload)
+
+        response2 = response.json()
+
+        # print(response2)
+
+
+        jobs = response2['jobID']
+
+
+        while True:
+            time.sleep(5)
+            url = "https://v2k-dev.vallarismaps.com/core/api/coverages/1.0-beta/manager/export/"+str(collection)+"/jobs/" + str(jobs)
+
+            payload = ""
+            headers = {
+              'API-Key': APIKey
+            }
+
+            response3 = requests.request("GET", url, headers=headers, data=payload)
+
+            response4 = response3.json()
+
+            
+            try :
+                if response4['code'] == 404 :
+                    res_out = "data permission"
+                    return res_out
+                    break
+            except:
+
+                if response4['status'] == 'succeed' or response4['status'] == 'failed':
+
+                    if response4['status'] == 'succeed':
+
+                        newpath = str(collection) 
+                        if not os.path.exists(newpath):
+                            os.makedirs(newpath)
+
+                        urllib.request.urlretrieve(response4['file'], newpath + "/"+str(collection)+".zip")
+
+                        with zipfile.ZipFile(newpath + "/" +str(collection) +".zip", 'r') as zip_ref:
+                            zip_ref.extractall(newpath)
+
+                        
+                        mypath = newpath + "/download/"
+                        onlyfiles = [f for f in listdir(mypath) if isfile(join(mypath, f))]
+                
+
+                        with zipfile.ZipFile(newpath + "/download/" +str(onlyfiles[0]), 'r') as zip_ref:
+                            zip_ref.extractall(newpath + "/download")
+                                
+                        name_out = str(onlyfiles[0][0:24])
+
+                        res_out = "succeed : " + newpath + '/download/' + name_out + '/IMAGERY.TIF'
+
+                    else :
+                        res_out = "failed" 
+
+                    break
+                else : 
+                    print("run processing")
+                    res_out = "run processing"
+
+                
+        return res_out
+    
+    
+    except Exception as e:
+        return 'error :' + str(e)
+            
\ No newline at end of file
