@@ -4,6 +4,7 @@
 ########### i-bitz company limited ##############
 ##################### 2020 ######################
 
+from distutils import ccompiler
 import time
 import tempfile
 import os
@@ -18,21 +19,26 @@ from tqdm import tqdm
 from shapely.geometry import Polygon
 
 
-def getData(storage, dataset_id, VallarisServer, Api_Key):
+
+def getData(dataset_id, VallarisServer, Api_Key):
     try:
         dir = tempfile.mkdtemp()
         local_filename = dir + "/" + str(dataset_id) + ".geojson"
-        
-        try: 
-            url = VallarisServer + "/1.0-beta/collections/" + str(dataset_id)+"/items/streaming"
+
+        try:
+            url = VallarisServer + "/1.0-beta/collections/" + \
+                str(dataset_id)+"/items/streaming"
 
             payload = {}
             headers = {
                 'API-Key': Api_Key
             }
-            response = requests.request("GET", url, headers=headers, data=payload)
-            print(response)
-            total_size_in_bytes = int(response.headers.get('content-length', 0))
+            response = requests.request(
+                "GET", url, headers=headers, data=payload)
+            # print(response)
+
+            total_size_in_bytes = int(
+                response.headers.get('content-length', 0))
             block_size = 1024  # 1 Kibibyte
             progress_bar = tqdm(total=total_size_in_bytes,
                                 unit='iB', unit_scale=True)
@@ -53,13 +59,13 @@ def getData(storage, dataset_id, VallarisServer, Api_Key):
 
             else:
                 readdata = gpd.read_file(local_filename, encoding='utf-8')
-                readdata.to_file(storage + '/' + dataset_id +
-                                '.gpkg', driver="GPKG")
+                readdata.to_file(dir + '/' + dataset_id +
+                                 '.gpkg', driver="GPKG")
 
                 if not os.path.exists(dir):
                     shutil.rmtree(dir)
 
-                return storage + '/' + dataset_id + '.gpkg'
+                return dir + '/' + dataset_id + '.gpkg'
         except:
             url = VallarisServer + "/core/api/features/1.0-beta/collections/" + \
                 str(dataset_id)+"/items/streaming"
@@ -67,9 +73,11 @@ def getData(storage, dataset_id, VallarisServer, Api_Key):
             headers = {
                 'API-Key': Api_Key
             }
-            response = requests.request("GET", url, headers=headers, data=payload)
+            response = requests.request(
+                "GET", url, headers=headers, data=payload)
             print(response)
-            total_size_in_bytes = int(response.headers.get('content-length', 0))
+            total_size_in_bytes = int(
+                response.headers.get('content-length', 0))
             block_size = 1024  # 1 Kibibyte
             progress_bar = tqdm(total=total_size_in_bytes,
                                 unit='iB', unit_scale=True)
@@ -90,21 +98,18 @@ def getData(storage, dataset_id, VallarisServer, Api_Key):
 
             else:
                 readdata = gpd.read_file(local_filename, encoding='utf-8')
-                readdata.to_file(storage + '/' + dataset_id +
-                                '.gpkg', driver="GPKG")
 
                 if not os.path.exists(dir):
                     shutil.rmtree(dir)
 
-                return storage + '/' + dataset_id + '.gpkg'
-
+                return readdata
 
     except Exception as e:
-        print(e)
+        # print(e)
         return 'something wrong'
 
 
-def getExport(storage, dataset_id, VallarisServer, Api_Key):
+def getExport(dataset_id, VallarisServer, Api_Key):
 
     try:
         dir = tempfile.mkdtemp()
@@ -135,20 +140,17 @@ def getExport(storage, dataset_id, VallarisServer, Api_Key):
         else:
             read_file = gpd.read_file(
                 dir + '/' + dataset_id + '.geojson', encoding='utf-8')
-            read_file.to_file(storage + '/' + dataset_id +
-                              '.geojson', encoding='utf-8', driver="GeoJSON")
-
             if not os.path.exists(dir):
                 shutil.rmtree(dir)
 
-            return storage + '/' + dataset_id + '.geojson'
+            return read_file
 
     except Exception as e:
-        print(e)
+        # print(e)
         return 'something wrong'
 
 
-def newCollection(storage, title, description, itemType, VallarisServer, Api_Key):
+def newCollection(title, description, itemType, VallarisServer, Api_Key):
     try:
         url = VallarisServer + "/core/api/features/1.0-beta/collections"
 
@@ -205,7 +207,7 @@ def newCollection(storage, title, description, itemType, VallarisServer, Api_Key
         return 'something wrong'
 
 
-def editCollection(storage, dataset_id, title, description, itemType, VallarisServer, Api_Key):
+def editCollection(dataset_id, title, description, itemType, VallarisServer, Api_Key):
     try:
         url = VallarisServer + \
             "/core/api/features/1.0-beta/collections/" + str(dataset_id)
@@ -260,7 +262,7 @@ def editCollection(storage, dataset_id, title, description, itemType, VallarisSe
         return 'something wrong'
 
 
-def delCollection(storage, dataset_id, VallarisServer, Api_Key):
+def delCollection(dataset_id, VallarisServer, Api_Key):
     try:
         url = VallarisServer + \
             "/core/api/features/1.0-beta/collections/" + str(dataset_id)
@@ -278,15 +280,19 @@ def delCollection(storage, dataset_id, VallarisServer, Api_Key):
         return 'something wrong'
 
 
-def getImport(storage, dataset_id, pathFile,  VallarisServer, Api_Key):
+def getImport(dataset_id, data,  VallarisServer, Api_Key):
     try:
         dir = tempfile.mkdtemp()
-        gdata = gpd.read_file(pathFile, encoding='utf-8')
+        gdata = data
         crt = len(gdata)
         print('total : ' + str(crt))
         max = 10
-        crt2 = crt//max
-        for i in range(0, crt2+1):
+
+        if crt <= max:
+            crt2 = 1
+        else:
+            crt2 = (crt//max) + 1
+        for i in range(0, crt2):
             st = 0 + (i*max)
             end = max + (i*max)
             out_data = gdata[st:end]
@@ -304,7 +310,6 @@ def getImport(storage, dataset_id, pathFile,  VallarisServer, Api_Key):
                 data = json.load(f)
 
             data_get = json.dumps(data, ensure_ascii=False)
-
             data2 = str(data_get).replace("'", '"')
             try:
                 data3 = str(data2).replace("None", '""')
@@ -330,10 +335,8 @@ def getImport(storage, dataset_id, pathFile,  VallarisServer, Api_Key):
             if res_code != False:
                 # print(res_code)
                 print('import error: ' + str(loop))
-                if not os.path.exists(storage + '/dataInvalid'):
-                    os.makedirs(storage + '/dataInvalid')
-                shutil.copy(dir + '/' + dataset_id + '_.geojson', storage + '/dataInvalid/' +
-                            dataset_id + '_' + str(loop-max) + '_' + str(loop)+'.geojson')
+                if not os.path.exists(dir + '/dataInvalid'):
+                    os.makedirs(dir + '/dataInvalid')
                 os.remove(dir + '/' + dataset_id + '_.geojson')
             else:
                 os.remove(dir + '/' + dataset_id + '_.geojson')
@@ -345,16 +348,33 @@ def getImport(storage, dataset_id, pathFile,  VallarisServer, Api_Key):
         return 'import success'
 
     except Exception as e:
-        print(e)
+        # print(e)
         return 'something wrong'
 
 
-def editFeatures(storage, dataset_id, features_id, data,  VallarisServer, Api_Key):
+def editFeatures(dataset_id, features_id, data,  VallarisServer, Api_Key):
 
     try:
+        dir = tempfile.mkdtemp()
+
+        data.to_file(dir + '/' + features_id + '_.geojson',
+                     encoding='utf-8', driver="GeoJSON", ensure_ascii=False)
+
+        with open(dir + '/' + features_id + '_.geojson', encoding='utf-8') as f:
+            data = json.load(f)
+
+        data_get = json.dumps(data, ensure_ascii=False)
+        data2 = str(data_get).replace("'", '"')
+        try:
+            data3 = str(data2).replace("None", '""')
+        except:
+            data3 = data2
+
+        data4 = json.loads(data3)
+
         url = VallarisServer + "/core/api/features/1.0-beta/collections/" + \
             str(dataset_id) + "/items/" + str(features_id)
-        payload = json.dumps(data)
+        payload = json.dumps(data4['features'][0])
         headers = {
             'API-Key': Api_Key,
             'Content-Type': 'application/json'
@@ -362,14 +382,21 @@ def editFeatures(storage, dataset_id, features_id, data,  VallarisServer, Api_Ke
 
         response = requests.request("PUT", url, headers=headers, data=payload)
         out_data = response.text
+
+        if not os.path.exists(dir):
+            shutil.rmtree(dir)
+
         return out_data
 
     except Exception as e:
-        print(e)
+        # print(e)
+        if not os.path.exists(dir):
+            shutil.rmtree(dir)
+
         return 'something wrong'
 
 
-def delFeatures(storage, dataset_id, features_id,  VallarisServer, Api_Key):
+def delFeatures(dataset_id, features_id,  VallarisServer, Api_Key):
 
     try:
         url = VallarisServer + "/core/api/features/1.0-beta/collections/" + \
@@ -391,7 +418,7 @@ def delFeatures(storage, dataset_id, features_id,  VallarisServer, Api_Key):
         return 'something wrong'
 
 
-def makeTile(storage, dataset_id, dataset_out, VallarisServer, Api_Key, parameter):
+def makeTile(dataset_id, dataset_out, VallarisServer, Api_Key, parameter):
     try:
         url = VallarisServer + \
             "/core/api/processes/vallaris/214bffaba098493005c5/" + \
@@ -409,4 +436,4 @@ def makeTile(storage, dataset_id, dataset_out, VallarisServer, Api_Key, paramete
 
     except Exception as e:
         print(e)
-        return 'something wrong'
+        return 'something wrong'
\ No newline at end of file
